pytilities.infinity — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »

# pytilities.infinity

Provides a cross-platform alternative to the platform dependent float(‘inf’).

`pytilities.infinity.` `infinity`

`pytilities.infinity.` `negative_infinity`

`pytilities.infinity.` `nan`

class `pytilities.infinity.` `_Base`
  `__copy__`()
  `__div__`(other)
  `__floordiv__`(other)
  `__ge__`(other)
  `__iadd__`(other)
  `__imul__`(other)
  `__isub__`(other)
  `__le__`(other)
  `__lt__`(other)
  `__mul__`(other)
  `__ne__`(other)
  `__pos__`()
  `__radd__`(other)
  `__rdiv__`(other)
  `__rfloordiv__`(other)
  `__rmul__`(other)
  `__rsub__`(other)
  `__rtruediv__`(other)
  `__sub__`(other)
  `__truediv__`(other)
  `__weakref__`

    list of weak references to the object (if defined)

class `pytilities.infinity.` `_NAN`
  `__add__`(other)
  `__div__`(other)
  `__eq__`(other)
  `__ge__`(other)
  `__gt__`(other)
  `__le__`(other)
  `__lt__`(other)
  `__mul__`(other)
  `__ne__`(other)
  `__neg__`()
  `__rdiv__`(other)
  `__str__`()

class `pytilities.infinity.` `_NegativeInfinity`
  `__add__`(other)
  `__eq__`(other)
  `__gt__`(other)
  `__neg__`()
  `__str__`()

class `pytilities.infinity.` `_PositiveInfinity`
  `__add__`(other)
  `__eq__`(other)
  `__gt__`(other)
  `__neg__`()
  `__str__`()

`pytilities.infinity.` `is_infinity`(number)

  Returns: | True if number is infinity or -infinity

`pytilities.infinity.` `is_nan`(number)

  Returns: | True if number is nan

`pytilities.infinity.` `is_negative_infinity`(number)

  Returns: | True if number is -infinity

`pytilities.infinity.` `is_positive_infinity`(number)

  Returns: | True if number is infinity

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »